# encoding: UTF-8
# frozen_string_literal: true

require_relative "helper"

class RegexpCollectionTest < Test::Unit::TestCase
  test "Numbers.integer" do
    regexp = Regexp::Collection::Numbers.integer
    assert_true "1".match?(regexp)
    assert_true "2".match?(regexp)
    assert_false "01".match?(regexp)
    assert_false "-0".match?(regexp)
    assert_false "-00".match?(regexp)
    assert_false "+0".match?(regexp)
    assert_false "+00".match?(regexp)
    assert_false "+1".match?(regexp)
    assert_true "-1".match?(regexp)
    assert_true "10".match?(regexp)
    assert_false "1xx".match?(regexp)
    assert_false "xx1".match?(regexp)
    assert_false "-x1".match?(regexp)
    assert_false "-1x".match?(regexp)
    assert_true "10".match?(regexp)
    assert_true "100".match?(regexp)
    assert_true "1000".match?(regexp)
    assert_true "9999".match?(regexp)
    assert_true "9000000".match?(regexp)
    assert_false "00".match?(regexp)
    assert_false " ".match?(regexp)
  end

  test "Numbers.decimal" do
    regexp = Regexp::Collection::Numbers.decimal
    assert_true "1".match?(regexp)
    assert_true "2".match?(regexp)
    assert_false "01".match?(regexp)
    assert_false "-0".match?(regexp)
    assert_false "+0".match?(regexp)
    assert_false "+1".match?(regexp)
    assert_true "-1".match?(regexp)
    assert_true "10".match?(regexp)
    assert_false "1xx".match?(regexp)
    assert_false "xx1".match?(regexp)
    assert_false "-x1".match?(regexp)
    assert_false "-1x".match?(regexp)
    assert_false "-1.5x".match?(regexp)
    assert_true "10".match?(regexp)
    assert_true "100".match?(regexp)
    assert_true "1000".match?(regexp)
    assert_true "9999".match?(regexp)
    assert_true "9000000".match?(regexp)
    assert_false "-0.0".match?(regexp)
    assert_false "+0.0".match?(regexp)
    assert_false "+1.0".match?(regexp)
    assert_true "-1.0".match?(regexp)
    assert_true "0.0".match?(regexp)
    assert_false "+00.0".match?(regexp)
  end

  test "Numbers.natural(true)" do
    regexp = Regexp::Collection::Numbers.natural(true)
    assert_true "0".match?(regexp)
    assert_false "-0".match?(regexp)
    assert_false "+0".match?(regexp)
    assert_false "0.0".match?(regexp)
    assert_false "-0.0".match?(regexp)
    assert_false "+0.0".match?(regexp)
    assert_false "00".match?(regexp)
    assert_true "1".match?(regexp)
    assert_false "-1".match?(regexp)
    assert_false "+1".match?(regexp)
    assert_false "1.0".match?(regexp)
    assert_false "-1.0".match?(regexp)
    assert_false "+1.0".match?(regexp)
    assert_false "1.1".match?(regexp)
    assert_false "-1.1".match?(regexp)
    assert_false "+1.1".match?(regexp)
    assert_false "foo".match?(regexp)
    assert_false "0foo".match?(regexp)
    assert_false "-0foo".match?(regexp)
    assert_false "+0foo".match?(regexp)
    assert_false "1foo".match?(regexp)
    assert_false "-1foo".match?(regexp)
    assert_false "+1foo".match?(regexp)
    assert_true "16".match?(regexp)
  end

  test "Numbers.natural(false)" do
    regexp = Regexp::Collection::Numbers.natural(false)
    assert_false "0".match?(regexp)
    assert_false "-0".match?(regexp)
    assert_false "+0".match?(regexp)
    assert_false "0.0".match?(regexp)
    assert_false "-0.0".match?(regexp)
    assert_false "+0.0".match?(regexp)
    assert_false "00".match?(regexp)
    assert_true "1".match?(regexp)
    assert_false "-1".match?(regexp)
    assert_false "+1".match?(regexp)
    assert_false "1.0".match?(regexp)
    assert_false "-1.0".match?(regexp)
    assert_false "+1.0".match?(regexp)
    assert_false "1.1".match?(regexp)
    assert_false "-1.1".match?(regexp)
    assert_false "+1.1".match?(regexp)
    assert_false "foo".match?(regexp)
    assert_false "0foo".match?(regexp)
    assert_false "-0foo".match?(regexp)
    assert_false "+0foo".match?(regexp)
    assert_false "1foo".match?(regexp)
    assert_false "-1foo".match?(regexp)
    assert_false "+1foo".match?(regexp)
    assert_true "16".match?(regexp)
  end

  test "Time.seconds_required" do
    regexp = Regexp::Collection::Time.seconds_required
    assert_false "".match?(regexp)
    assert_false "foo".match?(regexp)
    assert_false "12".match?(regexp)
    assert_false "12:11".match?(regexp)
    assert_false "12:11:".match?(regexp)
    assert_true "12:11:10".match?(regexp)
    assert_false "+12:11:10".match?(regexp)
    assert_false "12:11:10foo".match?(regexp)
    assert_false "12:11:60".match?(regexp)
    assert_true "23:59:59".match?(regexp)
    assert_false "24:00:00".match?(regexp)
    assert_false "1:00".match?(regexp)
    assert_true "1:00:00".match?(regexp)
    assert_false "01:00".match?(regexp)
    assert_true "01:00:00".match?(regexp)
    assert_false "12:0:0".match?(regexp)
    assert_true "12:10:09".match?(regexp)
    assert_false "12:10:09.111".match?(regexp)
  end

  test "Time.seconds_optional" do
    regexp = Regexp::Collection::Time.seconds_optional
    assert_false "".match?(regexp)
    assert_false "foo".match?(regexp)
    assert_false "12".match?(regexp)
    assert_true "12:11".match?(regexp)
    assert_false "12:11:".match?(regexp)
    assert_true "12:11:10".match?(regexp)
    assert_false "+12:11:10".match?(regexp)
    assert_false "12:11:10foo".match?(regexp)
    assert_false "12:11:60".match?(regexp)
    assert_true "23:59".match?(regexp)
    assert_true "23:59:59".match?(regexp)
    assert_false "24:00:00".match?(regexp)
    assert_true "1:00:00".match?(regexp)
    assert_true "1:00".match?(regexp)
    assert_true "01:00:00".match?(regexp)
    assert_true "01:00".match?(regexp)
    assert_false "12:0:0".match?(regexp)
    assert_true "12:10:09".match?(regexp)
    assert_false "12:10:09.111".match?(regexp)
  end

  test "Time.seconds_not_permitted" do
    regexp = Regexp::Collection::Time.seconds_not_permitted
    assert_false "".match?(regexp)
    assert_false "foo".match?(regexp)
    assert_false "12".match?(regexp)
    assert_true "12:11".match?(regexp)
    assert_false "12:11:".match?(regexp)
    assert_false "12:11:10".match?(regexp)
    assert_false "+12:11:10".match?(regexp)
    assert_false "12:11:10foo".match?(regexp)
    assert_false "12:11:60".match?(regexp)
    assert_true "23:59".match?(regexp)
    assert_false "23:59:59".match?(regexp)
    assert_false "24:00:00".match?(regexp)
    assert_false "1:00:00".match?(regexp)
    assert_true "1:00".match?(regexp)
    assert_false "01:00:00".match?(regexp)
    assert_true "01:00".match?(regexp)
    assert_false "12:0:0".match?(regexp)
    assert_false "12:10:09".match?(regexp)
    assert_false "12:10:09.111".match?(regexp)
  end
end
